"""Layer 7 Utilities constants."""

__app_name__ = "Layer-7-Utilities"
__description__ = "This is a set of utilities used by https://Layer7.Solutions for the software tools we create. It includes a logger with default configuration information we setup as well as an oAuth wrapper to be able to pull login information from a custom database."
__author__ = "Layer 7 Solutions (Mike Wohlrab)"
__version__ = "1.2.10"
